pub struct CreateMsg {
pub id: String,
pub hash: String,
pub recipient: String,
pub expires: Expiration,
}Fields
id: Stringid is a human-readable name for the swap to use later. 3-20 bytes of utf-8 text
hash: StringThis is hex-encoded sha-256 hash of the preimage (must be 32*2 = 64 chars)
recipient: StringIf approved, funds go to the recipient
expires: ExpirationYou can set expiration at time or at block height the contract is valid at. After the contract is expired, it can be returned to the original funder.